==> HorsePower-1.11.2-1.6.1.38-sources.jar: se/gory_moon/horsepower/util/HorsePowerCommand.java <==
package se.gory_moon.horsepower.util;

import com.google.common.collect.Lists;
import net.minecraft.client.Minecraft;
import net.minecraft.client.entity.EntityPlayerSP;
import net.minecraft.command.CommandBase;
import net.minecraft.command.CommandException;
import net.minecraft.command.ICommandSender;
import net.minecraft.command.WrongUsageException;
import net.minecraft.entity.Entity;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.RayTraceResult;
import net.minecraft.util.text.TextComponentTranslation;
import net.minecraftforge.client.IClientCommand;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import javax.annotation.Nullable;
import java.awt.*;
import java.awt.datatransfer.StringSelection;
import java.util.Collections;
import java.util.List;

@SideOnly(Side.CLIENT)
public class HorsePowerCommand extends CommandBase implements IClientCommand {

    @Override
    public String func_71517_b() {
        return "horsepower";
    }

    @Override
    public String func_71518_a(ICommandSender sender) {
        return "commands.horsepower.usage";
    }

    @Override
    public List<String> func_71514_a() {
        return Lists.newArrayList("hp");
    }

    @Override
    public int func_82362_a()
    {
        return 2;
    }

    @Override
    public void func_184881_a(MinecraftServer server, ICommandSender sender, String[] args) throws CommandException {
        if (args.length == 1) {
            if ("entity".equals(args[0])) {
                if (sender instanceof EntityPlayerSP) {
                    RayTraceResult result = Minecraft.func_71410_x().field_71476_x;

                    if (result != null && result.field_72313_a == RayTraceResult.Type.ENTITY) {
                        Entity entity = result.field_72308_g;
                        sender.func_145747_a(new TextComponentTranslation("commands.horsepower.entity.has", entity.getClass().getName()));
                        try {
                            StringSelection selection = new StringSelection(entity.getClass().getName());
                            Toolkit.getDefaultToolkit().getSystemClipboard().setContents(selection, selection);
                        } catch (Exception ignored){}
                    } else
                        sender.func_145747_a(new TextComponentTranslation("commands.horsepower.entity.no"));
                } else
                    throw new CommandException("commands.horsepower.entity.invalid");
                return;
            } else if ("reload".equals(args[0])) {
                throw new CommandException("commands.horsepower.reload");
            }
        }
        throw new WrongUsageException(func_71518_a(sender));
    }

    @Override
    public List<String> func_184883_a(MinecraftServer server, ICommandSender sender, String[] args, @Nullable BlockPos targetPos) {
        return args.length == 1 ? func_71530_a(args, "entity"): Collections.emptyList();
    }

    @Override
    public boolean allowUsageWithoutPrefix(ICommandSender sender, String message) {
        return false;
    }
}

==> HorsePower-1.12.2-2.6.1.68-sources.jar: se/gory_moon/horsepower/util/HorsePowerCommand.java <==
package se.gory_moon.horsepower.util;

import com.google.common.collect.Lists;
import net.minecraft.client.Minecraft;
import net.minecraft.client.entity.EntityPlayerSP;
import net.minecraft.command.CommandBase;
import net.minecraft.command.CommandException;
import net.minecraft.command.ICommandSender;
import net.minecraft.command.WrongUsageException;
import net.minecraft.entity.Entity;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.RayTraceResult;
import net.minecraft.util.text.Style;
import net.minecraft.util.text.TextComponentTranslation;
import net.minecraft.util.text.TextFormatting;
import net.minecraftforge.client.IClientCommand;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import se.gory_moon.horsepower.HPEventHandler;
import se.gory_moon.horsepower.recipes.HPRecipes;

import javax.annotation.Nullable;
import java.awt.*;
import java.awt.datatransfer.StringSelection;
import java.util.Collections;
import java.util.List;

@SideOnly(Side.CLIENT)
public class HorsePowerCommand extends CommandBase implements IClientCommand {

    @Override
    public String func_71517_b() {
        return "horsepower";
    }

    @Override
    public String func_71518_a(ICommandSender sender) {
        return "commands.horsepower.usage";
    }

    @Override
    public List<String> func_71514_a() {
        return Lists.newArrayList("hp");
    }

    @Override
    public int func_82362_a()
    {
        return 2;
    }

    @Override
    public void func_184881_a(MinecraftServer server, ICommandSender sender, String[] args) throws CommandException {
        if (args.length == 1) {
            if ("entity".equals(args[0])) {
                if (sender instanceof EntityPlayerSP) {
                    RayTraceResult result = Minecraft.func_71410_x().field_71476_x;

                    if (result != null && result.field_72313_a == RayTraceResult.Type.ENTITY) {
                        Entity entity = result.field_72308_g;
                        sender.func_145747_a(new TextComponentTranslation("commands.horsepower.entity.has", entity.getClass().getName()));
                        try {
                            StringSelection selection = new StringSelection(entity.getClass().getName());
                            Toolkit.getDefaultToolkit().getSystemClipboard().setContents(selection, selection);
                        } catch (Exception ignored){}
                    } else
                        sender.func_145747_a(new TextComponentTranslation("commands.horsepower.entity.no"));
                } else
                    throw new CommandException("commands.horsepower.entity.invalid");
                return;
            } if ("reload".equals(args[0])) {
                sender.func_145747_a(new TextComponentTranslation("commands.horsepower.reload").func_150255_a(new Style().func_150238_a(TextFormatting.YELLOW).func_150227_a(true)));
                HPEventHandler.reloadConfig();
                boolean hasErrors = HPRecipes.ERRORS.size() > 0;
                Utils.sendSavedErrors();
                if (hasErrors)
                    sender.func_145747_a(new TextComponentTranslation("commands.horsepower.reload.error").func_150255_a(new Style().func_150238_a(TextFormatting.DARK_RED).func_150227_a(true)));
                else
                    sender.func_145747_a(new TextComponentTranslation("commands.horsepower.reload.noerror").func_150255_a(new Style().func_150238_a(TextFormatting.GREEN).func_150227_a(true)));
                return;
            }
        }
        throw new WrongUsageException(func_71518_a(sender));
    }

    @Override
    public List<String> func_184883_a(MinecraftServer server, ICommandSender sender, String[] args, @Nullable BlockPos targetPos) {
        return args.length == 1 ? func_71530_a(args, "entity", "reload"): Collections.emptyList();
    }

    @Override
    public boolean allowUsageWithoutPrefix(ICommandSender sender, String message) {
        return false;
    }
}
